<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
require 'config.php';
require_once ABSPATH . '/google-api-php-client/vendor/autoload.php';
use Google\Client;
use Google\Service\Drive;
use Google\Service\Drive\DriveFile;

// Path to the service account key file
$keyFilePath = SERVICE_ACCOUNT_KEY;
// Create Google client
$client = new Client();
$client->setAuthConfig($keyFilePath);
$client->addScope(Google_Service_Drive::DRIVE);
// Create Google Drive service
$service = new Drive($client);
// Directory to backup
$backupDir = BACKUP_DIRECTORY;
// Destination folder ID in Google Drive
$folderId = GOOGLE_DRIVE_DIRECTORY;
date_default_timezone_set("Asia/Tokyo");
// Create the metadata for the new subfolder

$todayDate = date('Y-m-d');
$subfolderExists = false;
$pageToken = null;
$subFolderId = null;

do {
    $response = $service->files->listFiles([
        'q' => "name='$todayDate' and mimeType='application/vnd.google-apps.folder' and '$folderId' in parents",
        'spaces' => 'drive',
        'pageToken' => $pageToken,
    ]);

    foreach ($response->getFiles() as $file) {
        // Subfolder with today's date already exists
        $subfolderExists = true;
        $subFolderId = $file->getId();
        break;
    }

    $pageToken = $response->getNextPageToken();
} while ($pageToken != null);


if (!$subfolderExists) {
    // Create the metadata for the new subfolder
    $subFolderMetadata = new DriveFile([
        'name' => $todayDate,
        'mimeType' => 'application/vnd.google-apps.folder',
        'parents' => [$folderId],
    ]);

    // Create the new subfolder in Google Drive
    $subFolder = $service->files->create($subFolderMetadata);

    if ($subFolder) {
        $subFolderId = $subFolder->getId();
        //echo "Subfolder '$todayDate' created successfully.\n";
    }
}

$response = array(
    "success" => array(),
    "failed" => array()
);

if ($subFolderId) {
    // Iterate through files in backup directory
    $files = scandir($backupDir);
    foreach ($files as $file) {
        // Skip . and .. directories
        if ($file == '.' || $file == '..') {
            continue;
        }
        // File to upload
        $filePath = $backupDir . '/' . $file;
        $fileName = basename($filePath);
        // Create file metadata
        $fileMetadata = new DriveFile([
            'name' => $fileName,
            'parents' => [$subFolderId],
        ]);
        // Upload file
        $uploadedFile = $service->files->create(
            $fileMetadata,
            [
                'data' => file_get_contents($filePath),
                'mimeType' => mime_content_type($filePath),
                'uploadType' => 'multipart',
                'fields' => 'id',
            ]
        );
        // Check response
        if ($uploadedFile) {
            $success = array("fileName" => $fileName, "fileID" => $uploadedFile->id);
            array_push($response["success"], $success);
        } else {
            $failed = array("fileName" => $fileName);
            array_push($response["failed"], $failed);
        }
    }
    echo '<pre>';
    print_r($response);
    echo '</pre>';
}else{
    echo '<pre>';
    echo 'Can not found sub folder.';
    echo '</pre>';
}